@@ -139,11 +139,14 @@ static void add_interface(void* data, struct wl_registry* registry, uint32_t nam
 	}
 }
 
-static void config_surface(void* data, struct zwlr_layer_surface_v1* surface, uint32_t serial, uint32_t _width, uint32_t _height) {
+static void config_surface(void* data, struct zwlr_layer_surface_v1* surface, uint32_t serial, uint32_t width, uint32_t height) {
 	(void) data;
-	(void) _width;
-	(void) _height;
+	(void) width;
+	(void) height;
 	zwlr_layer_surface_v1_ack_configure(surface, serial);
+}
+
+static void setup_surface(struct zwlr_layer_surface_v1* surface) {
 	zwlr_layer_surface_v1_set_size(surface, width, height);
 	zwlr_layer_surface_v1_set_keyboard_interactivity(surface, true);
 
@@ -1291,9 +1294,19 @@ static gboolean key_press(GtkWidget* widget, GdkEvent* event, gpointer data) {
 		GList* children = gtk_flow_box_get_selected_children(GTK_FLOW_BOX(inner_box));
 		if(gtk_widget_has_focus(entry)) {
 			g_signal_emit_by_name(entry, "activate", entry, NULL);
-		} else if(gtk_widget_has_focus(inner_box) || (children->data != NULL && gtk_widget_has_focus(children->data))) {
-			if(children->data != NULL) {
-				g_signal_emit_by_name(children->data, "activate", children->data, NULL);
+		} else if(gtk_widget_has_focus(inner_box) || children->data != NULL) {
+			gpointer obj = children->data;
+
+			if(obj != NULL) {
+				GtkWidget* exp = gtk_bin_get_child(GTK_BIN(obj));
+				if(GTK_IS_EXPANDER(exp)) {
+					GtkWidget* box = gtk_bin_get_child(GTK_BIN(exp));
+					GtkListBoxRow* row = gtk_list_box_get_selected_row(GTK_LIST_BOX(box));
+					if(row != NULL) {
+						obj = row;
+					}
+				}
+				g_signal_emit_by_name(obj, "activate", obj, NULL);
 			}
 		}
 		g_list_free(children);
@@ -1721,6 +1734,7 @@ void wofi_init(struct map* _config) {
 		}
 
 		wlr_surface = zwlr_layer_shell_v1_get_layer_surface(shell, wl_surface, output, wlr_layer, "wofi");
+		setup_surface(wlr_surface);
 		struct zwlr_layer_surface_v1_listener* surface_listener = malloc(sizeof(struct zwlr_layer_surface_v1_listener));
 		surface_listener->configure = config_surface;
 		surface_listener->closed = nop;
